@@ -3,6 +3,7 @@ import os
 from guide_bot.scan_visualization.interface_plot_sum import PlotSum
 from guide_bot.scan_visualization.interface_compare_monitors_scan import CompareMonitorsScan
 from guide_bot.scan_visualization.interface_compare_monitors import CompareMonitors
+from guide_bot.scan_visualization.interface_compare_sources import CompareSources
 from guide_bot.scan_visualization.interface_any_monitor import PlotAnyMonitor
 from guide_bot.scan_visualization.interface_guide_geometry import PlotGuideGeometry
 
@@ -21,6 +22,7 @@ class Results:
         self.plot_sum_interface = None
         self.compare_monitors_scan_interface = None
         self.compare_monitors_interface = None
+        self.compare_moderators_interface = None
         self.plot_any_monitors_interface = None
         self.plot_guide_interface = None
 
@@ -68,6 +70,16 @@ class Results:
         interface = self.get_compare_monitors()
         return interface.show_interface()
 
+    def get_compare_moderators(self):
+        if self.compare_moderators_interface is None:
+            self.compare_moderators_interface = CompareSources(self.overview)
+
+        return self.compare_moderators_interface
+
+    def compare_moderators(self):
+        interface = self.get_compare_moderators()
+        return interface.show_interface()
+
     def get_compare_monitors_scan(self):
         if len(self.get_scanned_parameters()) == 0:
             raise RuntimeError("Loaded dataset does not contain a scan.")
